AlbumCache class

Implemented types

Constructors

AlbumCache(AlbumRepository reference)

Properties

fullCache → Map<String?, AlbumModel?>
final
hashCode → int
The hash code for this object.
no setterinherited
reference → AlbumRepository
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(AlbumModel value) → Future<AlbumModel>
Add a AlbumModel to the repository, cached
override
addEntity(String documentID, AlbumEntity value) → Future<AlbumEntity>
Add a AlbumEntity to the repository, cached
override
changeValue(String documentId, String fieldName, num changeByThisValue) → Future<AlbumModel>
override
delete(AlbumModel value) → Future<void>
Delete a AlbumModel from the repository, cached
override
deleteAll() → Future<void>
override
flush() → void
override
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → AlbumEntity?
override
get(String? id, {dynamic onError(Exception)?}) → Future<AlbumModel?>
Retrieve a AlbumModel with it's id, cached
override
getEntity(String? id, {dynamic onError(Exception)?}) → Future<AlbumEntity?>
override
getSubCollection(String documentId, String name) → dynamic
override
listen(AlbumModelTrigger trigger, {String? orderBy, bool? descending, Object? startAfter, int? limit, int? privilegeLevel, EliudQuery? eliudQuery}) → StreamSubscription<List<AlbumModel?>>
override
listenTo(String documentId, AlbumChanged changed, {AlbumErrorHandler? errorHandler}) → StreamSubscription<AlbumModel?>
override
listenWithDetails(AlbumModelTrigger trigger, {String? orderBy, bool? descending, Object? startAfter, int? limit, int? privilegeLevel, EliudQuery? eliudQuery}) → StreamSubscription<List<AlbumModel?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
timeStampToString(dynamic timeStamp) → String?
override
toString() → String
A string representation of this object.
inherited
update(AlbumModel value) → Future<AlbumModel>
Update a AlbumModel
override
updateEntity(String documentID, AlbumEntity value) → Future<AlbumEntity>
Update a AlbumEntity in the repository, cached
override
values({String? orderBy, bool? descending, Object? startAfter, int? limit, SetLastDoc? setLastDoc, int? privilegeLevel, EliudQuery? eliudQuery}) → Stream<List<AlbumModel?>>
Retrieve list of List<AlbumModel?>
override
valuesList({String? orderBy, bool? descending, Object? startAfter, int? limit, SetLastDoc? setLastDoc, int? privilegeLevel, EliudQuery? eliudQuery}) → Future<List<AlbumModel?>>
override
valuesListWithDetails({String? orderBy, bool? descending, Object? startAfter, int? limit, SetLastDoc? setLastDoc, int? privilegeLevel, EliudQuery? eliudQuery}) → Future<List<AlbumModel?>>
override
valuesWithDetails({String? orderBy, bool? descending, Object? startAfter, int? limit, SetLastDoc? setLastDoc, int? privilegeLevel, EliudQuery? eliudQuery}) → Stream<List<AlbumModel?>>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

refreshRelations(AlbumModel model) → Future<AlbumModel>